@@ -5,6 +5,11 @@ from mloptm.methods import (
     Secant
 )
 
+from mloptm.grads import (
+    SteepestDescent,
+    NewtonND
+)
 
-__version__ = "1.0.4"
+
+__version__ = "1.0.5"
 
